Girder Coverage Report

# Girder Coverage Report: 90%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 2871 | 275 | 64 | 90%
girder/__init__ | 26 | 0 | 0 | 100%
girder/__main__ | 0 | 0 | 11 | 100%
girder/api/__init__ | 0 | 0 | 0 | 100%
girder/api/api_main | 23 | 1 | 0 | 96%
girder/api/describe | 49 | 1 | 0 | 98%
girder/api/docs | 19 | 0 | 0 | 100%
girder/api/rest | 186 | 15 | 15 | 92%
girder/api/v1/__init__ | 0 | 0 | 0 | 100%
girder/api/v1/assetstore | 48 | 7 | 0 | 85%
girder/api/v1/collection | 56 | 13 | 0 | 77%
girder/api/v1/file | 63 | 3 | 0 | 95%
girder/api/v1/folder | 96 | 18 | 0 | 81%
girder/api/v1/group | 119 | 3 | 0 | 97%
girder/api/v1/item | 87 | 4 | 0 | 95%
girder/api/v1/resource | 30 | 0 | 0 | 100%
girder/api/v1/system | 49 | 11 | 0 | 78%
girder/api/v1/user | 124 | 4 | 0 | 97%
girder/constants | 36 | 1 | 0 | 97%
girder/events | 63 | 1 | 0 | 98%
girder/models/__init__ | 18 | 2 | 0 | 89%
girder/models/assetstore | 65 | 9 | 0 | 86%
girder/models/collection | 51 | 5 | 0 | 90%
girder/models/file | 54 | 4 | 2 | 93%
girder/models/folder | 107 | 12 | 0 | 89%
girder/models/group | 163 | 19 | 3 | 88%
girder/models/item | 116 | 9 | 0 | 92%
girder/models/model_base | 230 | 36 | 2 | 84%
girder/models/password | 46 | 4 | 0 | 91%
girder/models/setting | 38 | 9 | 0 | 76%
girder/models/token | 20 | 0 | 0 | 100%
girder/models/upload | 46 | 2 | 0 | 96%
girder/models/user | 88 | 5 | 2 | 94%
girder/utility/__init__ | 0 | 0 | 0 | 100%
girder/utility/abstract_assetstore_adapter | 10 | 2 | 5 | 80%
girder/utility/assetstore_utilities | 20 | 6 | 0 | 70%
girder/utility/config | 29 | 7 | 0 | 76%
girder/utility/dev_endpoints | 9 | 4 | 0 | 56%
girder/utility/filesystem_assetstore_adapter | 94 | 8 | 0 | 91%
girder/utility/gridfs_assetstore_adapter | 82 | 3 | 0 | 96%
girder/utility/mail_utils | 33 | 1 | 0 | 97%
girder/utility/model_importer | 23 | 1 | 4 | 96%
girder/utility/plugin_utilities | 78 | 14 | 0 | 82%
girder/utility/server | 31 | 2 | 1 | 94%
girder/utility/sha512_state | 21 | 0 | 0 | 100%
girder/utility/webroot | 23 | 4 | 0 | 83%
girder/utility/ziputil | 122 | 24 | 4 | 80%
plugins/geoJSON/server/__init__ | 34 | 0 | 2 | 100%
plugins/geoJSON/server/features | 117 | 0 | 13 | 100%
plugins/mongo_search/server/__init__ | 29 | 1 | 0 | 97%